.. _release_history:

Release and Version History
==============================================================================


x.y.z (Backlog)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

**Minor Improvements**

**Bugfixes**

**Miscellaneous**


0.1.2 (2024-07-29)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Bugfixes**

- Fix DynamoDB ORM Schema error.


0.1.1 (2024-07-27) YANKED
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- First Release.
- Add the following public APIs:
    - ``acore_server_monitoring_core.api.make_dynamodb_table_name``
    - ``acore_server_monitoring_core.api.UseCaseEnum``
    - ``acore_server_monitoring_core.api.Measurement``
    - ``acore_server_monitoring_core.api.WorldServerStatusMeasurement``
    - ``acore_server_monitoring_core.api.Ec2RdsStatusMeasurement``
